@@ -6,15 +6,14 @@ from ..dsl import Protein
 from ..struct import BELGraph
 
 vegf_graph = BELGraph()
-vegf = Protein(namespace='fplx', name='VEGF')
-vegfr = Protein(namespace='fplx', name='VEGFR')
+vegf = Protein(namespace="fplx", name="VEGF")
+vegfr = Protein(namespace="fplx", name="VEGFR")
 
-ev = 'VEGF activates the endothelial VEGF receptors' \
-     ' (VEGFR) 1 and 2, and VEGF-C activates VEGFR-3 and VEGFR-2.'
+ev = "VEGF activates the endothelial VEGF receptors" " (VEGFR) 1 and 2, and VEGF-C activates VEGFR-3 and VEGFR-2."
 
 vegf_graph.add_activates(
     vegf,
     vegfr,
     evidence=ev,
-    citation='9506953',
+    citation="9506953",
 )
