@@ -25,9 +25,29 @@ from networkx.utils import open_file
 
 from ..canonicalize import calculate_canonical_name
 from ..constants import (
-    ANNOTATIONS, CITATION, EVIDENCE, FUSION, GRAPH_ANNOTATION_LIST, GRAPH_ANNOTATION_PATTERN, GRAPH_ANNOTATION_URL,
-    GRAPH_METADATA, GRAPH_NAMESPACE_PATTERN, GRAPH_NAMESPACE_URL, MEMBERS, NAME, PARTNER_3P, PARTNER_5P, PRODUCTS,
-    RANGE_3P, RANGE_5P, REACTANTS, RELATION, SOURCE_MODIFIER, TARGET_MODIFIER, UNQUALIFIED_EDGES, VARIANTS,
+    ANNOTATIONS,
+    CITATION,
+    EVIDENCE,
+    FUSION,
+    GRAPH_ANNOTATION_LIST,
+    GRAPH_ANNOTATION_PATTERN,
+    GRAPH_ANNOTATION_URL,
+    GRAPH_METADATA,
+    GRAPH_NAMESPACE_PATTERN,
+    GRAPH_NAMESPACE_URL,
+    MEMBERS,
+    NAME,
+    PARTNER_3P,
+    PARTNER_5P,
+    PRODUCTS,
+    RANGE_3P,
+    RANGE_5P,
+    REACTANTS,
+    RELATION,
+    SOURCE_MODIFIER,
+    TARGET_MODIFIER,
+    UNQUALIFIED_EDGES,
+    VARIANTS,
 )
 from ..dsl import BaseAbundance, BaseEntity
 from ..language import Entity
@@ -36,63 +56,51 @@ from ..tokens import parse_result_to_dsl
 from ..utils import expand_dict, flatten_dict
 
 __all__ = [
-    'to_cx',
-    'to_cx_file',
-    'to_cx_gz',
-    'to_cx_jsons',
-    'from_cx',
-    'from_cx_file',
-    'from_cx_gz',
-    'from_cx_jsons',
-    'NDEX_SOURCE_FORMAT',
+    "to_cx",
+    "to_cx_file",
+    "to_cx_gz",
+    "to_cx_jsons",
+    "from_cx",
+    "from_cx_file",
+    "from_cx_gz",
+    "from_cx_jsons",
+    "NDEX_SOURCE_FORMAT",
 ]
 
 log = logging.getLogger(__name__)
 
-CX_NODE_NAME = 'label'
+CX_NODE_NAME = "label"
 NDEX_SOURCE_FORMAT = "ndex:sourceFormat"
 
-NDEX_SOURCE_MODIFIER = 'sourceModifier'
-NDEX_TARGET_MODIFIER = 'targetModifier'
+NDEX_SOURCE_MODIFIER = "sourceModifier"
+NDEX_TARGET_MODIFIER = "targetModifier"
 
 
-def _cx_to_dict(list_of_dicts: List[Dict], key_tag: str = 'k', value_tag: str = 'v') -> Dict:
+def _cx_to_dict(list_of_dicts: List[Dict], key_tag: str = "k", value_tag: str = "v") -> Dict:
     """Convert a CX list of dictionaries to a flat dictionary."""
-    return {
-        d[key_tag]: d[value_tag]
-        for d in list_of_dicts
-    }
+    return {d[key_tag]: d[value_tag] for d in list_of_dicts}
 
 
 def _cleanse_fusion_dict(d: Dict) -> Dict:
     """Fix the fusion partner names."""
-    return {
-        k.replace('_', ''): v
-        for k, v in d.items()
-    }
+    return {k.replace("_", ""): v for k, v in d.items()}
 
 
 _p_dict = {
-    'partner5p': PARTNER_5P,
-    'partner3p': PARTNER_3P,
-    'range5p': RANGE_5P,
-    'range3p': RANGE_3P,
+    "partner5p": PARTNER_5P,
+    "partner3p": PARTNER_3P,
+    "range5p": RANGE_5P,
+    "range3p": RANGE_3P,
 }
 
 
 def _restore_fusion_dict(d: Dict) -> Dict:
-    return {
-        _p_dict[k]: v
-        for k, v in d.items()
-    }
+    return {_p_dict[k]: v for k, v in d.items()}
 
 
 def build_node_mapping(graph: BELGraph) -> Mapping[BaseEntity, int]:
     """Build a mapping from a graph's nodes to their canonical sort order."""
-    return {
-        node: node_index
-        for node_index, node in enumerate(sorted(graph, key=methodcaller('as_bel')))
-    }
+    return {node: node_index for node_index, node in enumerate(sorted(graph, key=methodcaller("as_bel")))}
 
 
 def to_cx(graph: BELGraph) -> List[Dict]:  # noqa: C901
@@ -111,12 +119,12 @@ def to_cx(graph: BELGraph) -> List[Dict]:  # noqa: C901
         node_index_data[node_index] = node
 
         node_entry_dict = {
-            '@id': node_index,
-            'n': calculate_canonical_name(node),
+            "@id": node_index,
+            "n": calculate_canonical_name(node),
         }
 
         if isinstance(node, BaseAbundance):
-            node_entry_dict['r'] = node.curie
+            node_entry_dict["r"] = node.curie
 
         nodes_entry.append(node_entry_dict)
 
@@ -125,51 +133,63 @@ def to_cx(graph: BELGraph) -> List[Dict]:  # noqa: C901
             aliases.extend(xref.curie for xref in node.xrefs)
 
         if aliases:
-            node_attributes_entry.append({
-                'po': node_index,
-                'n': 'alias',
-                'v': aliases,
-                'd': 'list_of_str',
-            })
+            node_attributes_entry.append(
+                {
+                    "po": node_index,
+                    "n": "alias",
+                    "v": aliases,
+                    "d": "list_of_str",
+                }
+            )
 
         for k, v in node.items():
             if k == VARIANTS:
                 for i, el in enumerate(v):
                     for a, b in flatten_dict(el).items():
-                        node_attributes_entry.append({
-                            'po': node_index,
-                            'n': '{}_{}_{}'.format(k, i, a),
-                            'v': b,
-                        })
+                        node_attributes_entry.append(
+                            {
+                                "po": node_index,
+                                "n": "{}_{}_{}".format(k, i, a),
+                                "v": b,
+                            }
+                        )
             elif k == FUSION:
                 v = _cleanse_fusion_dict(v)
                 for a, b in flatten_dict(v).items():
-                    node_attributes_entry.append({
-                        'po': node_index,
-                        'n': '{}_{}'.format(k, a),
-                        'v': b,
-                    })
+                    node_attributes_entry.append(
+                        {
+                            "po": node_index,
+                            "n": "{}_{}".format(k, a),
+                            "v": b,
+                        }
+                    )
 
             elif k == NAME:
-                node_attributes_entry.append({
-                    'po': node_index,
-                    'n': CX_NODE_NAME,
-                    'v': v,
-                })
+                node_attributes_entry.append(
+                    {
+                        "po": node_index,
+                        "n": CX_NODE_NAME,
+                        "v": v,
+                    }
+                )
 
             elif k in {PRODUCTS, REACTANTS, MEMBERS}:
-                node_attributes_entry.append({
-                    'po': node_index,
-                    'n': k,
-                    'v': json.dumps(v),
-                })
+                node_attributes_entry.append(
+                    {
+                        "po": node_index,
+                        "n": k,
+                        "v": json.dumps(v),
+                    }
+                )
 
             else:
-                node_attributes_entry.append({
-                    'po': node_index,
-                    'n': k,
-                    'v': v,
-                })
+                node_attributes_entry.append(
+                    {
+                        "po": node_index,
+                        "n": k,
+                        "v": v,
+                    }
+                )
 
     edges_entry = []
     edge_attributes_entry = []
@@ -178,51 +198,63 @@ def to_cx(graph: BELGraph) -> List[Dict]:  # noqa: C901
         uid = node_mapping[source]
         vid = node_mapping[target]
 
-        edges_entry.append({
-            '@id': edge_index,
-            's': uid,
-            't': vid,
-            'i': d[RELATION],
-        })
+        edges_entry.append(
+            {
+                "@id": edge_index,
+                "s": uid,
+                "t": vid,
+                "i": d[RELATION],
+            }
+        )
 
         if EVIDENCE in d:
-            edge_attributes_entry.append({
-                'po': edge_index,
-                'n': EVIDENCE,
-                'v': d[EVIDENCE],
-            })
+            edge_attributes_entry.append(
+                {
+                    "po": edge_index,
+                    "n": EVIDENCE,
+                    "v": d[EVIDENCE],
+                }
+            )
 
             for k, v in d[CITATION].items():
-                edge_attributes_entry.append({
-                    'po': edge_index,
-                    'n': '{}_{}'.format(CITATION, k),
-                    'v': v,
-                })
+                edge_attributes_entry.append(
+                    {
+                        "po": edge_index,
+                        "n": "{}_{}".format(CITATION, k),
+                        "v": v,
+                    }
+                )
 
         if ANNOTATIONS in d:
             for annotation, values in d[ANNOTATIONS].items():
-                edge_attributes_entry.append({
-                    'po': edge_index,
-                    'n': annotation,
-                    'v': sorted(values, key=lambda e: (e.namespace, e.identifier, e.name)),
-                    'd': 'list_of_string',
-                })
+                edge_attributes_entry.append(
+                    {
+                        "po": edge_index,
+                        "n": annotation,
+                        "v": sorted(values, key=lambda e: (e.namespace, e.identifier, e.name)),
+                        "d": "list_of_string",
+                    }
+                )
 
         if SOURCE_MODIFIER in d:
             for k, v in flatten_dict(d[SOURCE_MODIFIER]).items():
-                edge_attributes_entry.append({
-                    'po': edge_index,
-                    'n': '{}_{}'.format(NDEX_SOURCE_MODIFIER, k),
-                    'v': v,
-                })
+                edge_attributes_entry.append(
+                    {
+                        "po": edge_index,
+                        "n": "{}_{}".format(NDEX_SOURCE_MODIFIER, k),
+                        "v": v,
+                    }
+                )
 
         if TARGET_MODIFIER in d:
             for k, v in flatten_dict(d[TARGET_MODIFIER]).items():
-                edge_attributes_entry.append({
-                    'po': edge_index,
-                    'n': '{}_{}'.format(NDEX_TARGET_MODIFIER, k),
-                    'v': v,
-                })
+                edge_attributes_entry.append(
+                    {
+                        "po": edge_index,
+                        "n": "{}_{}".format(NDEX_TARGET_MODIFIER, k),
+                        "v": v,
+                    }
+                )
 
     context_legend = {}
 
@@ -243,19 +275,23 @@ def to_cx(graph: BELGraph) -> List[Dict]:  # noqa: C901
 
     context_legend_entry = []
     for keyword, resource_type in context_legend.items():
-        context_legend_entry.append({
-            'k': keyword,
-            'v': resource_type,
-        })
+        context_legend_entry.append(
+            {
+                "k": keyword,
+                "v": resource_type,
+            }
+        )
 
     annotation_list_keys_lookup = {keyword: i for i, keyword in enumerate(sorted(graph.annotation_list))}
     annotation_lists_entry = []
     for keyword, values in graph.annotation_list.items():
         for v in values:
-            annotation_lists_entry.append({
-                'k': annotation_list_keys_lookup[keyword],
-                'v': v,
-            })
+            annotation_lists_entry.append(
+                {
+                    "k": annotation_list_keys_lookup[keyword],
+                    "v": v,
+                }
+            )
 
     context_entry_dict = {}
     context_entry_dict.update(graph.namespace_url)
@@ -267,29 +303,33 @@ def to_cx(graph: BELGraph) -> List[Dict]:  # noqa: C901
     context_entry_dict.update(graph.namespace_url)
     context_entry = [context_entry_dict]
 
-    network_attributes_entry = [{
-        "n": NDEX_SOURCE_FORMAT,
-        "v": "PyBEL",
-    }]
+    network_attributes_entry = [
+        {
+            "n": NDEX_SOURCE_FORMAT,
+            "v": "PyBEL",
+        }
+    ]
     for k, v in graph.document.items():
-        network_attributes_entry.append({
-            'n': k,
-            'v': v,
-        })
+        network_attributes_entry.append(
+            {
+                "n": k,
+                "v": v,
+            }
+        )
 
     # Coalesce to cx
     # cx = create_aspect.number_verification()
-    cx = [{'numberVerification': [{'longNumber': 281474976710655}]}]
+    cx = [{"numberVerification": [{"longNumber": 281474976710655}]}]
 
     cx_pairs = [
-        ('@context', context_entry),
-        ('context_legend', context_legend_entry),
-        ('annotation_lists', annotation_lists_entry),
-        ('networkAttributes', network_attributes_entry),
-        ('nodes', nodes_entry),
-        ('nodeAttributes', node_attributes_entry),
-        ('edges', edges_entry),
-        ('edgeAttributes', edge_attributes_entry),
+        ("@context", context_entry),
+        ("context_legend", context_legend_entry),
+        ("annotation_lists", annotation_lists_entry),
+        ("networkAttributes", network_attributes_entry),
+        ("nodes", nodes_entry),
+        ("nodeAttributes", node_attributes_entry),
+        ("edges", edges_entry),
+        ("edgeAttributes", edge_attributes_entry),
     ]
 
     cx_metadata = []
@@ -304,26 +344,30 @@ def to_cx(graph: BELGraph) -> List[Dict]:  # noqa: C901
             "version": "1.0",
         }
 
-        if key in {'citations', 'supports', 'nodes', 'edges'}:
-            aspect_dict['idCounter'] = len(aspect)
+        if key in {"citations", "supports", "nodes", "edges"}:
+            aspect_dict["idCounter"] = len(aspect)
 
         cx_metadata.append(aspect_dict)
 
-    cx.append({
-        'metaData': cx_metadata,
-    })
+    cx.append(
+        {
+            "metaData": cx_metadata,
+        }
+    )
 
     for key, aspect in cx_pairs:
-        cx.append({
-            key: aspect,
-        })
+        cx.append(
+            {
+                key: aspect,
+            }
+        )
 
     cx.append({"status": [{"error": "", "success": True}]})
 
     return cx
 
 
-@open_file(1, mode='w')
+@open_file(1, mode="w")
 def to_cx_file(graph: BELGraph, path: Union[str, TextIO], indent: Optional[int] = 2, **kwargs) -> None:
     """Write a BEL graph to a JSON file in CX format.
 
@@ -357,7 +401,7 @@ def to_cx_file(graph: BELGraph, path: Union[str, TextIO], indent: Optional[int]
 
 def to_cx_gz(graph, path: str, **kwargs) -> None:
     """Write a graph as CX JSON to a gzip file."""
-    with gzip.open(path, 'wt') as file:
+    with gzip.open(path, "wt") as file:
         json.dump(to_cx(graph), file, ensure_ascii=False, **kwargs)
 
 
@@ -395,29 +439,29 @@ def from_cx(cx: List[Dict]) -> BELGraph:  # noqa: C901
     meta_entries = defaultdict(list)
 
     for key, value in _iterate_list_of_dicts(cx):
-        if key == 'context_legend':
+        if key == "context_legend":
             context_legend_aspect.extend(value)
 
-        elif key == 'annotation_lists':
+        elif key == "annotation_lists":
             annotation_lists_aspect.extend(value)
 
-        elif key == '@context':
+        elif key == "@context":
             for element in value:
                 context_entry.update(element)
 
-        elif key == 'networkAttributes':
+        elif key == "networkAttributes":
             network_attributes_aspect.extend(value)
 
-        elif key == 'nodes':
+        elif key == "nodes":
             nodes_aspect.extend(value)
 
-        elif key == 'nodeAttributes':
+        elif key == "nodeAttributes":
             node_attributes_aspect.extend(value)
 
-        elif key == 'edges':
+        elif key == "edges":
             edges_aspect.extend(value)
 
-        elif key == 'edgeAttributes':
+        elif key == "edgeAttributes":
             edge_annotations_aspect.extend(value)
 
         else:
@@ -427,7 +471,7 @@ def from_cx(cx: List[Dict]) -> BELGraph:  # noqa: C901
 
     annotation_lists = defaultdict(set)
     for data in annotation_lists_aspect:
-        annotation_lists[data['k']].add(data['v'])
+        annotation_lists[data["k"]].add(data["v"])
 
     for keyword, entry in context_entry.items():
         if context_legend[keyword] == GRAPH_NAMESPACE_URL:
@@ -442,17 +486,17 @@ def from_cx(cx: List[Dict]) -> BELGraph:  # noqa: C901
             graph.annotation_list[keyword] = annotation_lists[entry]
 
     for data in network_attributes_aspect:
-        if data['n'] == NDEX_SOURCE_FORMAT:
+        if data["n"] == NDEX_SOURCE_FORMAT:
             continue
-        graph.graph[GRAPH_METADATA][data['n']] = data['v']
+        graph.graph[GRAPH_METADATA][data["n"]] = data["v"]
 
     node_name = {}
     for data in nodes_aspect:
-        node_name[data['@id']] = data['n']
+        node_name[data["@id"]] = data["n"]
 
     node_data = defaultdict(dict)
     for data in node_attributes_aspect:
-        node_data[data['po']][data['n']] = data['v']
+        node_data[data["po"]][data["n"]] = data["v"]
 
     # put all normal data here
     node_data_pp = defaultdict(dict)
@@ -468,7 +512,7 @@ def from_cx(cx: List[Dict]) -> BELGraph:  # noqa: C901
             if key.startswith(FUSION):
                 node_data_fusion[nid][key] = value
             elif key.startswith(VARIANTS):
-                _, i, vls = key.split('_', 2)
+                _, i, vls = key.split("_", 2)
                 node_data_variants[nid][i][vls] = value
             elif key in {PRODUCTS, REACTANTS, MEMBERS}:
                 node_data_pp[nid][key] = json.loads(value)
@@ -481,10 +525,7 @@ def from_cx(cx: List[Dict]) -> BELGraph:  # noqa: C901
         node_data_pp[nid].update(data)
 
     for nid, data in node_data_variants.items():
-        node_data_pp[nid][VARIANTS] = [
-            expand_dict(value)
-            for _, value in sorted(data.items())
-        ]
+        node_data_pp[nid][VARIANTS] = [expand_dict(value) for _, value in sorted(data.items())]
 
     nid_node_tuple = {}
     for nid, data in node_data_pp.items():
@@ -498,14 +539,14 @@ def from_cx(cx: List[Dict]) -> BELGraph:  # noqa: C901
     eid_source_nid = {}
     eid_target_nid = {}
     for data in edges_aspect:
-        eid = data['@id']
-        edge_relation[eid] = data['i']
-        eid_source_nid[eid] = data['s']
-        eid_target_nid[eid] = data['t']
+        eid = data["@id"]
+        edge_relation[eid] = data["i"]
+        eid_source_nid[eid] = data["s"]
+        eid_target_nid[eid] = data["t"]
 
     edge_data = defaultdict(dict)  # type: Dict[str, Dict[str, str]]
     for data in edge_annotations_aspect:
-        edge_data[data['po']][data['n']] = data['v']
+        edge_data[data["po"]][data["n"]] = data["v"]
 
     edge_citation = defaultdict(dict)  # type: Dict[str, Dict[str, str]]
     edge_subject = defaultdict(dict)
@@ -541,8 +582,7 @@ def from_cx(cx: List[Dict]) -> BELGraph:  # noqa: C901
     for eid in edge_relation:
         if eid in edge_annotations:  # FIXME stick this in edge_data.items() iteration
             edge_data_pp[eid][ANNOTATIONS] = {
-                key: [Entity(**v) for v in values]
-                for key, values in edge_annotations[eid].items()
+                key: [Entity(**v) for v in values] for key, values in edge_annotations[eid].items()
             }
 
         if eid in edge_citation:
@@ -563,17 +603,17 @@ def from_cx(cx: List[Dict]) -> BELGraph:  # noqa: C901
                 edge_relation[eid],
             )
         else:
-            raise ValueError('problem adding edge: {}'.format(eid))
+            raise ValueError("problem adding edge: {}".format(eid))
 
     return graph
 
 
 def _after_underscore(key):
-    _, vl = key.split('_', 1)
+    _, vl = key.split("_", 1)
     return vl
 
 
-@open_file(0, mode='r')
+@open_file(0, mode="r")
 def from_cx_file(path: Union[str, TextIO]) -> BELGraph:
     """Read a file containing CX JSON and converts to a BEL graph.
 
@@ -585,7 +625,7 @@ def from_cx_file(path: Union[str, TextIO]) -> BELGraph:
 
 def from_cx_gz(path: str) -> BELGraph:
     """Read a graph as CX JSON from a gzip file."""
-    with gzip.open(path, 'rt') as file:
+    with gzip.open(path, "rt") as file:
         return from_cx(json.load(file))
 
 
