@@ -4,5 +4,5 @@
 
 from .cli import main
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
