@@ -6,8 +6,8 @@ from .inline import to_jupyter, to_jupyter_str
 from .visualization import to_html, to_html_file
 
 __all__ = [
-    'to_html',
-    'to_html_file',
-    'to_jupyter',
-    'to_jupyter_str',
+    "to_html",
+    "to_html_file",
+    "to_jupyter",
+    "to_jupyter_str",
 ]
