@@ -13,9 +13,19 @@ from networkx.utils import open_file
 
 from .utils import ensure_version
 from ..constants import (
-    ANNOTATIONS, CITATION, FUSION, GRAPH_ANNOTATION_CURIE, GRAPH_ANNOTATION_LIST, GRAPH_ANNOTATION_MIRIAM, MEMBERS,
+    ANNOTATIONS,
+    CITATION,
+    FUSION,
+    GRAPH_ANNOTATION_CURIE,
+    GRAPH_ANNOTATION_LIST,
+    GRAPH_ANNOTATION_MIRIAM,
+    MEMBERS,
     PARTNER_3P,
-    PARTNER_5P, PRODUCTS, REACTANTS, SOURCE_MODIFIER, TARGET_MODIFIER,
+    PARTNER_5P,
+    PRODUCTS,
+    REACTANTS,
+    SOURCE_MODIFIER,
+    TARGET_MODIFIER,
 )
 from ..dsl import BaseEntity
 from ..language import citation_dict
@@ -25,16 +35,16 @@ from ..tokens import parse_result_to_dsl
 from ..utils import hash_edge, tokenize_version
 
 __all__ = [
-    'to_nodelink',
-    'to_nodelink_file',
-    'to_nodelink_gz',
-    'to_nodelink_jsons',
-    'from_nodelink',
-    'from_nodelink_file',
-    'from_nodelink_gz',
-    'from_nodelink_jsons',
-    'to_nodelink_gz_io',
-    'from_nodelink_gz_io',
+    "to_nodelink",
+    "to_nodelink_file",
+    "to_nodelink_gz",
+    "to_nodelink_jsons",
+    "from_nodelink",
+    "from_nodelink_file",
+    "from_nodelink_gz",
+    "from_nodelink_jsons",
+    "to_nodelink_gz_io",
+    "from_nodelink_gz_io",
 ]
 
 
@@ -45,7 +55,7 @@ def to_nodelink(graph: BELGraph) -> Mapping[str, Any]:
     """
     graph_json_dict = _to_nodelink_json_helper(graph)
 
-    _prepare_graph_dict(graph_json_dict['graph'])
+    _prepare_graph_dict(graph_json_dict["graph"])
 
     return graph_json_dict
 
@@ -53,15 +63,14 @@ def to_nodelink(graph: BELGraph) -> Mapping[str, Any]:
 def _prepare_graph_dict(g):
     # Convert annotation list definitions (which are sets) to canonicalized/sorted lists
     g[GRAPH_ANNOTATION_LIST] = {
-        keyword: list(sorted(values))
-        for keyword, values in g.get(GRAPH_ANNOTATION_LIST, {}).items()
+        keyword: list(sorted(values)) for keyword, values in g.get(GRAPH_ANNOTATION_LIST, {}).items()
     }
 
     g[GRAPH_ANNOTATION_CURIE] = list(sorted(g[GRAPH_ANNOTATION_CURIE]))
     g[GRAPH_ANNOTATION_MIRIAM] = list(sorted(g[GRAPH_ANNOTATION_MIRIAM]))
 
 
-@open_file(1, mode='w')
+@open_file(1, mode="w")
 def to_nodelink_file(graph: BELGraph, path: Union[str, TextIO], **kwargs) -> None:
     """Write this graph as node-link JSON to a file.
 
@@ -74,7 +83,7 @@ def to_nodelink_file(graph: BELGraph, path: Union[str, TextIO], **kwargs) -> Non
 
 def to_nodelink_gz(graph, path: str, **kwargs) -> None:
     """Write a graph as node-link JSON to a gzip file."""
-    with gzip.open(path, 'wt') as file:
+    with gzip.open(path, "wt") as file:
         json.dump(to_nodelink(graph), file, ensure_ascii=False, **kwargs)
 
 
@@ -85,14 +94,14 @@ def to_nodelink_jsons(graph: BELGraph, **kwargs) -> str:
 
 def from_nodelink(graph_json_dict: Mapping[str, Any], check_version: bool = True) -> BELGraph:
     """Build a graph from node-link JSON Object."""
-    pybel_version = tokenize_version(graph_json_dict['graph']['pybel_version'])
+    pybel_version = tokenize_version(graph_json_dict["graph"]["pybel_version"])
     if pybel_version[1] < 14:  # if minor version is less than 14
-        raise ValueError('Invalid NodeLink JSON from old version of PyBEL (v{}.{}.{})'.format(*pybel_version))
+        raise ValueError("Invalid NodeLink JSON from old version of PyBEL (v{}.{}.{})".format(*pybel_version))
     graph = _from_nodelink_json_helper(graph_json_dict)
     return ensure_version(graph, check_version=check_version)
 
 
-@open_file(0, mode='r')
+@open_file(0, mode="r")
 def from_nodelink_file(path: Union[str, TextIO], check_version: bool = True) -> BELGraph:
     """Build a graph from the node-link JSON contained in the given file.
 
@@ -103,7 +112,7 @@ def from_nodelink_file(path: Union[str, TextIO], check_version: bool = True) ->
 
 def from_nodelink_gz(path: str) -> BELGraph:
     """Read a graph as node-link JSON from a gzip file."""
-    with gzip.open(path, 'rt') as file:
+    with gzip.open(path, "rt") as file:
         return from_nodelink(json.load(file))
 
 
@@ -119,23 +128,20 @@ def _to_nodelink_json_helper(graph: BELGraph) -> Mapping[str, Any]:
 
     Adapted from :func:`networkx.readwrite.json_graph.node_link_data`
     """
-    nodes = sorted(graph, key=methodcaller('as_bel'))
+    nodes = sorted(graph, key=methodcaller("as_bel"))
 
     mapping = dict(zip(nodes, count()))
 
     return {
-        'directed': True,
-        'multigraph': True,
-        'graph': graph.graph.copy(),
-        'nodes': [
-            _augment_node(node)
-            for node in nodes
-        ],
-        'links': [
+        "directed": True,
+        "multigraph": True,
+        "graph": graph.graph.copy(),
+        "nodes": [_augment_node(node) for node in nodes],
+        "links": [
             dict(
                 chain(
                     data.copy().items(),
-                    [('source', mapping[u]), ('target', mapping[v]), ('key', key)],
+                    [("source", mapping[u]), ("target", mapping[v]), ("key", key)],
                 ),
             )
             for u, v, key, data in graph.edges(keys=True, data=True)
@@ -146,8 +152,8 @@ def _to_nodelink_json_helper(graph: BELGraph) -> Mapping[str, Any]:
 def _augment_node(node: BaseEntity) -> BaseEntity:
     """Add the SHA-512 identifier to a node's dictionary."""
     rv = node.copy()
-    rv['id'] = node.md5
-    rv['bel'] = node.as_bel()
+    rv["id"] = node.md5
+    rv["bel"] = node.as_bel()
     for m in chain(node.get(MEMBERS, []), node.get(REACTANTS, []), node.get(PRODUCTS, [])):
         m.update(_augment_node(m))
     if FUSION in node:
@@ -158,8 +164,7 @@ def _augment_node(node: BaseEntity) -> BaseEntity:
 
 def _recover_graph_dict(graph: BELGraph):
     graph.graph[GRAPH_ANNOTATION_LIST] = {
-        keyword: set(values)
-        for keyword, values in graph.graph.get(GRAPH_ANNOTATION_LIST, {}).items()
+        keyword: set(values) for keyword, values in graph.graph.get(GRAPH_ANNOTATION_LIST, {}).items()
     }
     graph.graph[GRAPH_ANNOTATION_CURIE] = set(graph.graph.get(GRAPH_ANNOTATION_CURIE, []))
     graph.graph[GRAPH_ANNOTATION_MIRIAM] = set(graph.graph.get(GRAPH_ANNOTATION_MIRIAM, []))
@@ -171,25 +176,21 @@ def _from_nodelink_json_helper(data: Mapping[str, Any]) -> BELGraph:
     Adapted from :func:`networkx.readwrite.json_graph.node_link_graph`
     """
     graph = BELGraph()
-    graph.graph = data.get('graph', {})
+    graph.graph = data.get("graph", {})
     _recover_graph_dict(graph)
 
     mapping = []
 
-    for node_data in data['nodes']:
+    for node_data in data["nodes"]:
         node = parse_result_to_dsl(node_data)
         graph.add_node_from_data(node)
         mapping.append(node)
 
-    for data in data['links']:
-        u = mapping[data['source']]
-        v = mapping[data['target']]
+    for data in data["links"]:
+        u = mapping[data["source"]]
+        v = mapping[data["target"]]
 
-        edge_data = {
-            k: v
-            for k, v in data.items()
-            if k not in {'source', 'target', 'key'}
-        }
+        edge_data = {k: v for k, v in data.items() if k not in {"source", "target", "key"}}
 
         for side in (SOURCE_MODIFIER, TARGET_MODIFIER):
             side_data = edge_data.get(side)
@@ -210,16 +211,16 @@ def _from_nodelink_json_helper(data: Mapping[str, Any]) -> BELGraph:
 def to_nodelink_gz_io(graph: BELGraph) -> BytesIO:
     """Get a BEL graph as a compressed BytesIO."""
     bytes_io = BytesIO()
-    with gzip.GzipFile(fileobj=bytes_io, mode='w') as file:
+    with gzip.GzipFile(fileobj=bytes_io, mode="w") as file:
         s = to_nodelink_jsons(graph)
-        file.write(s.encode('utf-8'))
+        file.write(s.encode("utf-8"))
     bytes_io.seek(0)
     return bytes_io
 
 
 def from_nodelink_gz_io(bytes_io: BytesIO) -> BELGraph:
     """Get BEL from gzipped nodelink JSON."""
-    with gzip.GzipFile(fileobj=bytes_io, mode='r') as file:
+    with gzip.GzipFile(fileobj=bytes_io, mode="r") as file:
         s = file.read()
-    j = s.decode('utf-8')
+    j = s.decode("utf-8")
     return from_nodelink_jsons(j)
