@@ -6,13 +6,44 @@ from abc import ABC, abstractmethod
 from typing import Dict, Tuple
 
 from ...constants import (
-    ACTIVITY, ASSOCIATION, CAUSAL_DECREASE_RELATIONS, CAUSAL_INCREASE_RELATIONS, CAUSAL_RELATIONS, CAUSES_NO_CHANGE,
-    CORRELATIVE_RELATIONS, DECREASES, DEGRADATION, DIRECTLY_DECREASES, DIRECTLY_INCREASES, EQUIVALENT_TO, HAS_PRODUCT,
-    HAS_REACTANT, HAS_VARIANT, INCREASES, IS_A, MODIFIER, PART_OF, REGULATES, RELATION, TARGET_MODIFIER,
+    ACTIVITY,
+    ASSOCIATION,
+    CAUSAL_DECREASE_RELATIONS,
+    CAUSAL_INCREASE_RELATIONS,
+    CAUSAL_RELATIONS,
+    CAUSES_NO_CHANGE,
+    CORRELATIVE_RELATIONS,
+    DECREASES,
+    DEGRADATION,
+    DIRECTLY_DECREASES,
+    DIRECTLY_INCREASES,
+    EQUIVALENT_TO,
+    HAS_PRODUCT,
+    HAS_REACTANT,
+    HAS_VARIANT,
+    INCREASES,
+    IS_A,
+    MODIFIER,
+    PART_OF,
+    REGULATES,
+    RELATION,
+    TARGET_MODIFIER,
 )
 from ...dsl import (
-    Abundance, BaseAbundance, BaseEntity, BiologicalProcess, CentralDogma, ComplexAbundance, Gene, MicroRna,
-    NamedComplexAbundance, Pathology, Population, Protein, Reaction, Rna,
+    Abundance,
+    BaseAbundance,
+    BaseEntity,
+    BiologicalProcess,
+    CentralDogma,
+    ComplexAbundance,
+    Gene,
+    MicroRna,
+    NamedComplexAbundance,
+    Pathology,
+    Population,
+    Protein,
+    Reaction,
+    Rna,
 )
 from ...typing import EdgeData
 
@@ -92,7 +123,7 @@ class HasVariantConverter(SimpleConverter, SimpleTypedPredicate):
 
 class _PartOfConverter(SimpleTypedPredicate, TypedConverter):
     relation = PART_OF
-    target_relation = 'partOf'
+    target_relation = "partOf"
 
 
 class PartOfNamedComplexConverter(_PartOfConverter):
@@ -113,9 +144,7 @@ class ProcessCausalConverter(SimpleConverter, SimpleTypedPredicate):
     def predicate(cls, u, v, key, edge_data) -> bool:
         """Test a BEL edge has a given relation."""
         return (
-            isinstance(u, cls.subject_type)
-            and edge_data[RELATION] in cls.relations
-            and isinstance(v, cls.object_type)
+            isinstance(u, cls.subject_type) and edge_data[RELATION] in cls.relations and isinstance(v, cls.object_type)
         )
 
 
@@ -172,20 +201,20 @@ class ReactionHasReactantConverter(_ReactionHasMemberConverter):
     """Converts BEL statements like ``rxn(X) hasReactant a(Y)``."""
 
     relation = HAS_REACTANT
-    target_relation = 'hasReactant'
+    target_relation = "hasReactant"
 
 
 class ReactionHasProductConverter(_ReactionHasMemberConverter):
     """Converts BEL statements like ``rxn(X) hasProduct a(Y)``."""
 
     relation = HAS_PRODUCT
-    target_relation = 'hasProduct'
+    target_relation = "hasProduct"
 
 
 class ReactionHasCatalystConverter(_ReactionTypedPredicate):
     """Converts BEL statements that simultaneously ``rxn(X) hasProduct a(Y)`` and ``rxn(X) hasReactant a(Y)``."""
 
-    target_relation = 'hasCatalyst'
+    target_relation = "hasCatalyst"
 
     @classmethod
     def predicate(cls, u: Reaction, v: BaseAbundance, key: str, edge_data: EdgeData) -> bool:
@@ -204,7 +233,7 @@ class ListComplexHasComponentConverter(SimpleTypedPredicate):
     subject_type = BaseAbundance
     relation = PART_OF
     object_type = ComplexAbundance
-    target_relation = 'partOf'
+    target_relation = "partOf"
 
     @classmethod
     def convert(cls, u: ComplexAbundance, v: BaseAbundance, key: str, data: Dict) -> Tuple[str, str, str]:
@@ -216,14 +245,14 @@ class IsAConverter(SimplePredicate, SimpleConverter):
     """Converts BEL statements like ``X isA Y``."""
 
     relation = IS_A
-    target_relation = 'isA'
+    target_relation = "isA"
 
 
 class EquivalenceConverter(SimplePredicate, SimpleConverter):
     """Converts BEL statements like ``X eq Y``."""
 
     relation = EQUIVALENT_TO
-    target_relation = 'equivalentTo'
+    target_relation = "equivalentTo"
 
 
 class CorrelationConverter(SimpleConverter):
@@ -246,7 +275,7 @@ class AssociationConverter(Converter):
     @staticmethod
     def convert(u: BaseAbundance, v: BaseAbundance, key: str, edge_data: EdgeData) -> Tuple[str, str, str]:
         """Convert a BEL edge."""
-        relation = edge_data.get('association_type', ASSOCIATION)  # allow more specific association to be defined
+        relation = edge_data.get("association_type", ASSOCIATION)  # allow more specific association to be defined
         return u.safe_label, relation, v.safe_label
 
 
@@ -274,7 +303,7 @@ class RegulatesAmountConverter(TypedConverter):
     """Converts BEL statements like ``A(B) reg C(D)``."""
 
     relation = REGULATES
-    target_relation = 'regulatesAmountOf'
+    target_relation = "regulatesAmountOf"
 
     @classmethod
     def predicate(cls, u: BaseEntity, v: BaseEntity, key: str, edge_data: EdgeData) -> bool:
@@ -287,111 +316,103 @@ class IncreasesAmountConverter(RegulatesAmountConverter):
     """Converts BEL statements like ``A(B) -> C(D)``."""
 
     relation = INCREASES
-    target_relation = 'increasesAmountOf'
+    target_relation = "increasesAmountOf"
 
 
 class DecreasesAmountConverter(RegulatesAmountConverter):
     """Converts BEL statements like ``A(B) -| C(D)``."""
 
     relation = DECREASES
-    target_relation = 'decreasesAmountOf'
+    target_relation = "decreasesAmountOf"
 
 
 class NoChangeAmountConverter(RegulatesAmountConverter):
     """Converts BEL statements like ``A(B) cnc C(D)``."""
 
     relation = CAUSES_NO_CHANGE
-    target_relation = 'notRegulatesAmountOf'
+    target_relation = "notRegulatesAmountOf"
 
 
 class RegulatesDegradationConverter(TypedConverter):
     """Converts BEL statements like ``A(B) reg deg(C(D))``."""
 
     relation = REGULATES
-    target_relation = 'regulatesAmountOf'
+    target_relation = "regulatesAmountOf"
 
     @classmethod
     def predicate(cls, u: BaseEntity, v: BaseEntity, key: str, edge_data: EdgeData) -> bool:
         """Test a BEL edge."""
         target_modifier = edge_data.get(TARGET_MODIFIER)
-        return (
-            edge_data[RELATION] == cls.relation
-            and target_modifier
-            and target_modifier.get(MODIFIER) == DEGRADATION
-        )
+        return edge_data[RELATION] == cls.relation and target_modifier and target_modifier.get(MODIFIER) == DEGRADATION
 
 
 class IncreasesDegradationConverter(RegulatesDegradationConverter):
     """Converts BEL statements like ``A(B) -> deg(C(D))``."""
 
     relation = INCREASES
-    target_relation = 'decreasesAmountOf'
+    target_relation = "decreasesAmountOf"
 
 
 class DecreasesDegradationConverter(RegulatesDegradationConverter):
     """Converts BEL statements like ``A(B) -| deg(C(D))``."""
 
     relation = DECREASES
-    target_relation = 'increasesAmountOf'
+    target_relation = "increasesAmountOf"
 
 
 class NoChangeDegradationConverter(RegulatesDegradationConverter):
     """Converts BEL statements like ``A(B) cnc deg(C(D))``."""
 
     relation = CAUSES_NO_CHANGE
-    target_relation = 'notRegulatesAmountOf'
+    target_relation = "notRegulatesAmountOf"
 
 
 class RegulatesActivityConverter(TypedConverter):
     """Converts BEL statements like ``A(B) reg act(C(D) [, ma(E)])``."""
 
     relation = REGULATES
-    target_relation = 'activityDirectlyRegulatesActivityOf'
+    target_relation = "activityDirectlyRegulatesActivityOf"
 
     @classmethod
     def predicate(cls, u: BaseEntity, v: BaseEntity, key: str, edge_data: EdgeData) -> bool:
         """Test a BEL edge."""
         target_modifier = edge_data.get(TARGET_MODIFIER)
-        return (
-            edge_data[RELATION] == cls.relation
-            and target_modifier
-            and target_modifier.get(MODIFIER) == ACTIVITY
-        )
+        return edge_data[RELATION] == cls.relation and target_modifier and target_modifier.get(MODIFIER) == ACTIVITY
 
 
 class IncreasesActivityConverter(RegulatesActivityConverter):
     """Converts BEL statements like ``A(B) -> act(C(D) [, ma(E)])``."""
 
     relation = INCREASES
-    target_relation = 'activityPositivelyRegulatesActivityOf'
+    target_relation = "activityPositivelyRegulatesActivityOf"
 
 
 class DirectlyIncreasesActivityConverter(RegulatesActivityConverter):
     """Converts BEL statements like ``A(B) => act(C(D) [, ma(E)])``."""
 
     relation = DIRECTLY_INCREASES
-    target_relation = 'activityDirectlyPositivelyRegulatesActivityOf'
+    target_relation = "activityDirectlyPositivelyRegulatesActivityOf"
 
 
 class DecreasesActivityConverter(RegulatesActivityConverter):
     """Converts BEL statements like ``A(B) -| act(C(D) [, ma(E)])``."""
 
     relation = DECREASES
-    target_relation = 'activityNegativelyRegulatesActivityOf'
+    target_relation = "activityNegativelyRegulatesActivityOf"
 
 
 class DirectlyDecreasesActivityConverter(RegulatesActivityConverter):
     """Converts BEL statements like ``A(B) =| act(C(D) [, ma(E)])``."""
 
     relation = DIRECTLY_DECREASES
-    target_relation = 'activityDirectlyNegativelyRegulatesActivityOf'
+    target_relation = "activityDirectlyNegativelyRegulatesActivityOf"
 
 
 class NoChangeActivityConverter(RegulatesActivityConverter):
     """Converts BEL statements like ``A(B) cnc act(C(D) [, ma(E)])``."""
 
     relation = CAUSES_NO_CHANGE
-    target_relation = 'notActivityDirectlyRegulatesActivityOf'
+    target_relation = "notActivityDirectlyRegulatesActivityOf"
 
 
 class AbundanceDirectlyDecreasesProteinActivityConverter(DirectlyDecreasesActivityConverter):
@@ -414,35 +435,35 @@ class MiRNARegulatesExpressionConverter(TypedConverter, SimpleTypedPredicate):
     subject_type = MicroRna
     relation = REGULATES
     object_type = Rna
-    target_relation = 'regulatesExpressionOf'
+    target_relation = "regulatesExpressionOf"
 
 
 class MiRNAIncreasesExpressionConverter(MiRNARegulatesExpressionConverter):
     """Converts BEL statements like ``m(X) -> r(Y)``."""
 
     relation = INCREASES
-    target_relation = 'increasesExpressionOf'
+    target_relation = "increasesExpressionOf"
 
 
 class MiRNADirectlyIncreasesExpressionConverter(MiRNARegulatesExpressionConverter):
     """Converts BEL statements like ``m(X) => r(Y)``."""
 
     relation = DIRECTLY_INCREASES
-    target_relation = 'increasesExpressionOf'
+    target_relation = "increasesExpressionOf"
 
 
 class MiRNADecreasesExpressionConverter(MiRNARegulatesExpressionConverter):
     """Converts BEL statements like ``m(X) -| r(Y)``."""
 
     relation = DECREASES
-    target_relation = 'repressesExpressionOf'
+    target_relation = "repressesExpressionOf"
 
 
 class MiRNADirectlyDecreasesExpressionConverter(MiRNARegulatesExpressionConverter):
     """Converts BEL statements like ``m(X) =| r(Y)``."""
 
     relation = DIRECTLY_DECREASES
-    target_relation = 'repressesExpressionOf'
+    target_relation = "repressesExpressionOf"
 
 
 class TranscriptionFactorForConverter(Converter):
@@ -494,7 +515,7 @@ class BindsProteinConverter(Converter):
     def convert(u: BaseEntity, v: BaseEntity, key: str, edge_data: EdgeData) -> Tuple[str, str, str]:
         """Convert a binds protein factor for edge."""
         v = [m for m in v.members if m != u][0]
-        return u.safe_label, 'bindsToProtein', v.safe_label
+        return u.safe_label, "bindsToProtein", v.safe_label
 
 
 class HomomultimerConverter(Converter):
@@ -513,7 +534,7 @@ class HomomultimerConverter(Converter):
     @staticmethod
     def convert(u: BaseEntity, v: BaseEntity, key: str, edge_data: EdgeData) -> Tuple[str, str, str]:
         """Convert a homomultimer formation."""
-        return u.safe_label, 'bindsToProtein', u.safe_label
+        return u.safe_label, "bindsToProtein", u.safe_label
 
 
 class BindsGeneConverter(Converter):
@@ -535,7 +556,7 @@ class BindsGeneConverter(Converter):
     def convert(u: BaseEntity, v: BaseEntity, key: str, edge_data: EdgeData) -> Tuple[str, str, str]:
         """Convert a transcription factor for edge."""
         v = [m for m in v.members if m != u][0]
-        return u.safe_label, 'bindsToGene', v.safe_label
+        return u.safe_label, "bindsToGene", v.safe_label
 
 
 class ProteinRegulatesComplex(Converter):
@@ -557,12 +578,12 @@ class ProteinRegulatesComplex(Converter):
         """Convert a transcription factor for edge."""
         relation = edge_data[RELATION]
         if relation in CAUSAL_INCREASE_RELATIONS:
-            relation = 'increasesAmountOf'
+            relation = "increasesAmountOf"
         elif relation in CAUSAL_DECREASE_RELATIONS:
-            relation = 'decreasesAmountOf'
+            relation = "decreasesAmountOf"
         elif relation == REGULATES:
-            relation = 'regulatesAmountOf'
+            relation = "regulatesAmountOf"
         else:
-            raise ValueError('invalid relation type')
+            raise ValueError("invalid relation type")
 
         return u.safe_label, relation, v.safe_label
