@@ -12,13 +12,13 @@ from sqlalchemy.orm import scoped_session, sessionmaker
 from .models import Base
 
 __all__ = [
-    'BaseManager',
-    'build_engine_session',
+    "BaseManager",
+    "build_engine_session",
 ]
 
 logger = logging.getLogger(__name__)
 
-X = TypeVar('X')
+X = TypeVar("X")
 
 
 def build_engine_session(
@@ -48,17 +48,26 @@ def build_engine_session(
     in most cases.
     """
     if connection is None:
-        raise ValueError('can not build engine when connection is None')
+        raise ValueError("can not build engine when connection is None")
 
     engine = create_engine(connection, echo=echo)
 
-    autoflush = pystow.get_config('pybel', 'manager_autoflush', passthrough=autoflush, dtype=bool, default=True)
-    autocommit = pystow.get_config('pybel', 'manager_autocommit', passthrough=autocommit, dtype=bool, default=False)
+    autoflush = pystow.get_config("pybel", "manager_autoflush", passthrough=autoflush, dtype=bool, default=True)
+    autocommit = pystow.get_config("pybel", "manager_autocommit", passthrough=autocommit, dtype=bool, default=False)
     expire_on_commit = pystow.get_config(
-        'pybel', 'manager_autoexpire', passthrough=expire_on_commit, dtype=bool, default=True,
+        "pybel",
+        "manager_autoexpire",
+        passthrough=expire_on_commit,
+        dtype=bool,
+        default=True,
     )
 
-    logger.debug('auto flush: %s, auto commit: %s, expire on commmit: %s', autoflush, autocommit, expire_on_commit)
+    logger.debug(
+        "auto flush: %s, auto commit: %s, expire on commmit: %s",
+        autoflush,
+        autocommit,
+        expire_on_commit,
+    )
 
     #: A SQLAlchemy session maker
     session_maker = sessionmaker(
@@ -117,4 +126,4 @@ class BaseManager(object):
         return self.session.query(model_cls).count()
 
     def __repr__(self):
-        return '<{} connection={}>'.format(self.__class__.__name__, self.engine.url)
+        return "<{} connection={}>".format(self.__class__.__name__, self.engine.url)
