@@ -7,14 +7,22 @@ from typing import Tuple, Type, Union
 
 from .utils import node_predicate
 from ..typing import NodePredicate
-from ....dsl import BaseEntity, CentralDogma, Fragment, GeneModification, Hgvs, ProteinModification, Variant
+from ....dsl import (
+    BaseEntity,
+    CentralDogma,
+    Fragment,
+    GeneModification,
+    Hgvs,
+    ProteinModification,
+    Variant,
+)
 
 __all__ = [
-    'has_variant',
-    'has_protein_modification',
-    'has_gene_modification',
-    'has_fragment',
-    'has_hgvs',
+    "has_variant",
+    "has_protein_modification",
+    "has_gene_modification",
+    "has_fragment",
+    "has_hgvs",
 ]
 
 
@@ -35,9 +43,10 @@ def _variant_checker(variant_cls: Union[Type[Variant], Tuple[Type[Variant], ...]
 
 def node_has_variant(node: BaseEntity, variant_cls) -> bool:
     """Return true if the node has at least one of the given variant."""
-    return isinstance(node, CentralDogma) and node.variants and any(
-        isinstance(variant, variant_cls)
-        for variant in node.variants
+    return (
+        isinstance(node, CentralDogma)
+        and node.variants
+        and any(isinstance(variant, variant_cls) for variant in node.variants)
     )
 
 
