@@ -6,4 +6,4 @@ from . import deletion, protein_rna_origins
 from .deletion import *
 from .protein_rna_origins import *
 
-__all__ = [k for k in locals() if not k.startswith('_')]
+__all__ = [k for k in locals() if not k.startswith("_")]
