@@ -2,7 +2,15 @@
 
 """Mutations that induce a sub-graph."""
 
-from . import annotations, citation, neighborhood, paths, random_subgraph, upstream, utils
+from . import (
+    annotations,
+    citation,
+    neighborhood,
+    paths,
+    random_subgraph,
+    upstream,
+    utils,
+)
 from .annotations import *
 from .citation import *
 from .neighborhood import *
@@ -11,4 +19,4 @@ from .random_subgraph import *
 from .upstream import *
 from .utils import *
 
-__all__ = [k for k in locals() if not k.startswith('_')]
+__all__ = [k for k in locals() if not k.startswith("_")]
