@@ -6,4 +6,4 @@ from . import protein_rna_origins, transfer
 from .protein_rna_origins import *
 from .transfer import *
 
-__all__ = [k for k in locals() if not k.startswith('_')]
+__all__ = [k for k in locals() if not k.startswith("_")]
