@@ -6,13 +6,17 @@ import networkx as nx
 
 from ..filters.edge_filters import filter_edges
 from ..filters.typing import EdgePredicates
-from ..pipeline import in_place_transformation, transformation, uni_in_place_transformation
+from ..pipeline import (
+    in_place_transformation,
+    transformation,
+    uni_in_place_transformation,
+)
 from ..utils import update_metadata
 
 __all__ = [
-    'remove_isolated_nodes',
-    'remove_isolated_nodes_op',
-    'expand_by_edge_filter',
+    "remove_isolated_nodes",
+    "remove_isolated_nodes_op",
+    "expand_by_edge_filter",
 ]
 
 
@@ -50,8 +54,7 @@ def expand_by_edge_filter(source, target, edge_predicates: EdgePredicates):
     :rtype: pybel.BELGraph
     """
     target.add_edges_from(
-        (u, v, k, source[u][v][k])
-        for u, v, k in filter_edges(source, edge_predicates=edge_predicates)
+        (u, v, k, source[u][v][k]) for u, v, k in filter_edges(source, edge_predicates=edge_predicates)
     )
 
     update_metadata(source, target)
