@@ -7,4 +7,4 @@ from .decorators import *
 from .exc import *
 from .pipeline import *
 
-__all__ = [k for k in locals() if not k.startswith('_')]
+__all__ = [k for k in locals() if not k.startswith("_")]
