@@ -7,4 +7,4 @@ from .query import Query
 from .seeding import SEED_DATA, SEED_METHOD, Seeding
 from .selection import get_subgraph
 
-__all__ = [k for k in locals() if not k.startswith('_')]
+__all__ = [k for k in locals() if not k.startswith("_")]
