@@ -10,19 +10,49 @@ from json import dumps
 from pybel import BELGraph
 from pybel.canonicalize import edge_to_bel
 from pybel.constants import (
-    ANNOTATIONS, ASSOCIATION, CITATION, CITATION_TYPE_PUBMED, DECREASES, DIRECTLY_DECREASES, EVIDENCE, IDENTIFIER,
-    INCREASES, LINE, METADATA_AUTHORS, METADATA_DESCRIPTION, METADATA_LICENSES, METADATA_NAME, METADATA_VERSION,
-    NAMESPACE, PART_OF, RELATION,
+    ANNOTATIONS,
+    ASSOCIATION,
+    CITATION,
+    CITATION_TYPE_PUBMED,
+    DECREASES,
+    DIRECTLY_DECREASES,
+    EVIDENCE,
+    IDENTIFIER,
+    INCREASES,
+    LINE,
+    METADATA_AUTHORS,
+    METADATA_DESCRIPTION,
+    METADATA_LICENSES,
+    METADATA_NAME,
+    METADATA_VERSION,
+    NAMESPACE,
+    PART_OF,
+    RELATION,
 )
 from pybel.dsl import BaseEntity, ComplexAbundance, Pathology, Protein
 from pybel.dsl.namespaces import hgnc
 from pybel.exceptions import (
-    BELParserWarning, BELSyntaxError, CitationTooShortException, IllegalAnnotationValueWarning,
+    BELParserWarning,
+    BELSyntaxError,
+    CitationTooShortException,
+    IllegalAnnotationValueWarning,
     InvalidCitationLengthException,
-    InvalidCitationType, InvalidFunctionSemantic, InvalidPubMedIdentifierWarning, MalformedTranslocationWarning,
-    MissingAnnotationKeyWarning, MissingAnnotationRegexWarning, MissingCitationException, MissingMetadataException,
-    MissingNamespaceNameWarning, MissingNamespaceRegexWarning, MissingSupportWarning, NakedNameWarning,
-    NestedRelationWarning, PlaceholderAminoAcidWarning, UndefinedAnnotationWarning, UndefinedNamespaceWarning,
+    InvalidCitationType,
+    InvalidFunctionSemantic,
+    InvalidPubMedIdentifierWarning,
+    MalformedTranslocationWarning,
+    MissingAnnotationKeyWarning,
+    MissingAnnotationRegexWarning,
+    MissingCitationException,
+    MissingMetadataException,
+    MissingNamespaceNameWarning,
+    MissingNamespaceRegexWarning,
+    MissingSupportWarning,
+    NakedNameWarning,
+    NestedRelationWarning,
+    PlaceholderAminoAcidWarning,
+    UndefinedAnnotationWarning,
+    UndefinedNamespaceWarning,
     VersionFormatWarning,
 )
 from pybel.language import Entity, citation_dict
@@ -31,29 +61,33 @@ from pybel.parser.parse_control import ControlParser
 from pybel.testing.constants import test_bel_thorough
 from pybel.utils import subdict_matches
 from tests.constant_helper import (
-    BEL_THOROUGH_EDGES, BEL_THOROUGH_NODES, citation_1, evidence_1, expected_test_simple_metadata,
+    BEL_THOROUGH_EDGES,
+    BEL_THOROUGH_NODES,
+    citation_1,
+    evidence_1,
+    expected_test_simple_metadata,
     expected_test_thorough_metadata,
 )
 
 logger = logging.getLogger(__name__)
 
-OPENBEL_DOMAIN = 'http://resources.openbel.org'
-OPENBEL_ANNOTATION_RESOURCES = OPENBEL_DOMAIN + '/belframework/20150611/annotation/'
+OPENBEL_DOMAIN = "http://resources.openbel.org"
+OPENBEL_ANNOTATION_RESOURCES = OPENBEL_DOMAIN + "/belframework/20150611/annotation/"
 
-test_citation_dict = citation_dict(namespace=CITATION_TYPE_PUBMED, identifier='1235813')
+test_citation_dict = citation_dict(namespace=CITATION_TYPE_PUBMED, identifier="1235813")
 
 SET_CITATION_TEST = f'SET Citation = {{"{test_citation_dict.namespace}", "{test_citation_dict.identifier}"}}'
-test_evidence_text = 'I read it on Twitter'
+test_evidence_text = "I read it on Twitter"
 test_set_evidence = f'SET Evidence = "{test_evidence_text}"'
 
-HGNC_KEYWORD = 'HGNC'
-MESH_DISEASES_KEYWORD = 'MeSHDisease'
+HGNC_KEYWORD = "HGNC"
+MESH_DISEASES_KEYWORD = "MeSHDisease"
 MESH_DISEASES_URL = OPENBEL_ANNOTATION_RESOURCES + "mesh-diseases.belanno"
 
-akt1 = hgnc(name='AKT1')
-egfr = hgnc(name='EGFR')
-fadd = hgnc(name='FADD')
-casp8 = hgnc(name='CASP8')
+akt1 = hgnc(name="AKT1")
+egfr = hgnc(name="EGFR")
+fadd = hgnc(name="FADD")
+casp8 = hgnc(name="CASP8")
 
 
 def update_provenance(control_parser: ControlParser) -> None:
@@ -70,19 +104,21 @@ def assert_has_node(self: unittest.TestCase, node: BaseEntity, graph: BELGraph,
     self.assertIn(
         node,
         graph,
-        msg='{} not found in graph. Other nodes:\n{}'.format(node.as_bel(), '\n'.join(
-            n.as_bel()
-            for n in graph
-        )),
+        msg="{} not found in graph. Other nodes:\n{}".format(node.as_bel(), "\n".join(n.as_bel() for n in graph)),
     )
 
     if kwargs:
         missing = set(kwargs) - set(graph.nodes[node])
-        self.assertFalse(missing, msg="Missing {} in node data".format(', '.join(sorted(missing))))
-        self.assertTrue(all(kwarg in graph.nodes[node] for kwarg in kwargs),
-                        msg="Missing kwarg in node data")
-        self.assertEqual(kwargs, {k: graph.nodes[node][k] for k in kwargs},
-                         msg="Wrong values in node data")
+        self.assertFalse(missing, msg="Missing {} in node data".format(", ".join(sorted(missing))))
+        self.assertTrue(
+            all(kwarg in graph.nodes[node] for kwarg in kwargs),
+            msg="Missing kwarg in node data",
+        )
+        self.assertEqual(
+            kwargs,
+            {k: graph.nodes[node][k] for k in kwargs},
+            msg="Wrong values in node data",
+        )
 
 
 def any_dict_matches(dict_of_dicts, query_dict) -> bool:
@@ -92,10 +128,7 @@ def any_dict_matches(dict_of_dicts, query_dict) -> bool:
     :param query_dict:
     :return:
     """
-    return any(
-        query_dict == sd
-        for sd in dict_of_dicts.values()
-    )
+    return any(query_dict == sd for sd in dict_of_dicts.values())
 
 
 def any_subdict_matches(dict_of_dicts, query_dict) -> bool:
@@ -105,10 +138,7 @@ def any_subdict_matches(dict_of_dicts, query_dict) -> bool:
     :param dict query_dict: dictionary
     :return: if dictionary target_dict matches one of the subdictionaries of a
     """
-    return any(
-        subdict_matches(sub_dict, query_dict)
-        for sub_dict in dict_of_dicts.values()
-    )
+    return any(subdict_matches(sub_dict, query_dict) for sub_dict in dict_of_dicts.values())
 
 
 def _remove_line(d):
@@ -124,7 +154,7 @@ def assert_has_edge(
     only: bool = False,
     permissive: bool = True,
     use_identifiers: bool = False,
-    **expected_edge_data
+    **expected_edge_data,
 ):
     """A helper function for checking if an edge with the given properties is contained within a graph."""
     self.assertIsInstance(u, BaseEntity)
@@ -132,10 +162,11 @@ def assert_has_edge(
 
     self.assertTrue(
         graph.has_edge(u, v),
-        msg='Edge ({}, {}) not in graph. Other edges:\n{}'.format(u, v, '\n'.join(
-            edge_to_bel(u, v, d, use_identifiers=use_identifiers)
-            for u, v, d in graph.edges(data=True)
-        ))
+        msg="Edge ({}, {}) not in graph. Other edges:\n{}".format(
+            u,
+            v,
+            "\n".join(edge_to_bel(u, v, d, use_identifiers=use_identifiers) for u, v, d in graph.edges(data=True)),
+        ),
     )
 
     if not expected_edge_data:
@@ -146,18 +177,19 @@ def assert_has_edge(
 
     if only:
         _key, actual_edge_data = list(graph[u][v].items())[0]
-        self.assertEqual(_remove_line(expected_edge_data), _remove_line(actual_edge_data), msg='Only entry not equal')
+        self.assertEqual(
+            _remove_line(expected_edge_data),
+            _remove_line(actual_edge_data),
+            msg="Only entry not equal",
+        )
     else:
-        actual_dicts = {
-            k: _remove_line(v)
-            for k, v in graph[u][v].items()
-        }
+        actual_dicts = {k: _remove_line(v) for k, v in graph[u][v].items()}
         if permissive:
             matches = any_subdict_matches(actual_dicts, _remove_line(expected_edge_data))
         else:
             matches = any_dict_matches(actual_dicts, _remove_line(expected_edge_data))
 
-        msg = 'No edge ({}, {}) with correct properties. expected:\n {}\nbut got:\n{}'.format(
+        msg = "No edge ({}, {}) with correct properties. expected:\n {}\nbut got:\n{}".format(
             u,
             v,
             dumps(expected_edge_data, indent=2, sort_keys=True),
@@ -173,7 +205,15 @@ class TestGraphMixin(unittest.TestCase):
         """Help assert node membership."""
         assert_has_node(self, n, g, **kwargs)
 
-    def assert_has_edge(self, g: BELGraph, u: BaseEntity, v: BaseEntity, only=False, permissive=True, **kwargs):
+    def assert_has_edge(
+        self,
+        g: BELGraph,
+        u: BaseEntity,
+        v: BaseEntity,
+        only=False,
+        permissive=True,
+        **kwargs,
+    ):
         """Help assert edge membership."""
         assert_has_edge(self, u, v, g, only=only, permissive=permissive, **kwargs)
 
@@ -189,18 +229,18 @@ class TestTokenParserBase(unittest.TestCase):
             autostreamline=False,
             disallow_unqualified_translocations=True,
             namespace_to_pattern={
-                'HGNC': re.compile(r'.*'),
-                'SNP': re.compile(r'.*'),
-                'CHEBI': re.compile(r'.*'),
-                'REF': re.compile(r'.*'),
-                'MOD': re.compile(r'.*'),
-                'EFO': re.compile(r'.*'),
-                'GO': re.compile(r'.*'),
-                'UBERON': re.compile(r'.*'),
-                'FPLX': re.compile(r'.*'),
-                'MESH': re.compile(r'.*'),
-                'MGI': re.compile(r'.*'),
-                'dbSNP': re.compile(r'.*'),
+                "HGNC": re.compile(r".*"),
+                "SNP": re.compile(r".*"),
+                "CHEBI": re.compile(r".*"),
+                "REF": re.compile(r".*"),
+                "MOD": re.compile(r".*"),
+                "EFO": re.compile(r".*"),
+                "GO": re.compile(r".*"),
+                "UBERON": re.compile(r".*"),
+                "FPLX": re.compile(r".*"),
+                "MESH": re.compile(r".*"),
+                "MGI": re.compile(r".*"),
+                "dbSNP": re.compile(r".*"),
             },
         )
 
@@ -230,17 +270,17 @@ def help_check_hgnc(test_case: unittest.TestCase, namespace_dict) -> None:
     """Assert that the namespace dictionary is correct."""
     test_case.assertIn(HGNC_KEYWORD, namespace_dict)
 
-    mhs2 = '7071', 'MHS2'
+    mhs2 = "7071", "MHS2"
     test_case.assertIn(mhs2, namespace_dict[HGNC_KEYWORD])
-    test_case.assertEqual(set('G'), set(namespace_dict[HGNC_KEYWORD][mhs2]))
+    test_case.assertEqual(set("G"), set(namespace_dict[HGNC_KEYWORD][mhs2]))
 
-    miatnb = '50731', 'MIATNB'
+    miatnb = "50731", "MIATNB"
     test_case.assertIn(miatnb, namespace_dict[HGNC_KEYWORD])
-    test_case.assertEqual(set('GR'), set(namespace_dict[HGNC_KEYWORD][miatnb]))
+    test_case.assertEqual(set("GR"), set(namespace_dict[HGNC_KEYWORD][miatnb]))
 
-    mia = '7076', 'MIA'
+    mia = "7076", "MIA"
     test_case.assertIn(mia, namespace_dict[HGNC_KEYWORD])
-    test_case.assertEqual(set('GRP'), set(namespace_dict[HGNC_KEYWORD][mia]))
+    test_case.assertEqual(set("GRP"), set(namespace_dict[HGNC_KEYWORD][mia]))
 
 
 class BelReconstitutionMixin(TestGraphMixin):
@@ -274,59 +314,101 @@ class BelReconstitutionMixin(TestGraphMixin):
         bel_simple_citation_2 = citation_dict(namespace=CITATION_TYPE_PUBMED, identifier="123456")
 
         evidence_1_extra = "Evidence 1 w extra notes"
-        evidence_2 = 'Evidence 2'
-        evidence_3 = 'Evidence 3'
+        evidence_2 = "Evidence 2"
+        evidence_3 = "Evidence 3"
 
-        assert_has_edge(self, akt1, egfr, graph, only=True, **{
-            RELATION: INCREASES,
-            CITATION: bel_simple_citation_1,
-            EVIDENCE: evidence_1_extra,
-            ANNOTATIONS: {
-                'Species': [Entity(namespace='Species', identifier='9606')],
-            }
-        })
-        assert_has_edge(self, egfr, fadd, graph, only=True, **{
-            RELATION: DECREASES,
-            ANNOTATIONS: {
-                'Species': [Entity(namespace='Species', identifier='9606')],
-                'CellLine': [Entity(namespace='CellLine', identifier='10B9 cell')],
+        assert_has_edge(
+            self,
+            akt1,
+            egfr,
+            graph,
+            only=True,
+            **{
+                RELATION: INCREASES,
+                CITATION: bel_simple_citation_1,
+                EVIDENCE: evidence_1_extra,
+                ANNOTATIONS: {
+                    "Species": [Entity(namespace="Species", identifier="9606")],
+                },
             },
-            CITATION: bel_simple_citation_1,
-            EVIDENCE: evidence_2
-        })
-        assert_has_edge(self, egfr, casp8, graph, only=True, **{
-            RELATION: DIRECTLY_DECREASES,
-            ANNOTATIONS: {
-                'Species': [Entity(namespace='Species', identifier='9606')],
-                'CellLine': [Entity(namespace='CellLine', identifier='10B9 cell')],
+        )
+        assert_has_edge(
+            self,
+            egfr,
+            fadd,
+            graph,
+            only=True,
+            **{
+                RELATION: DECREASES,
+                ANNOTATIONS: {
+                    "Species": [Entity(namespace="Species", identifier="9606")],
+                    "CellLine": [Entity(namespace="CellLine", identifier="10B9 cell")],
+                },
+                CITATION: bel_simple_citation_1,
+                EVIDENCE: evidence_2,
             },
-            CITATION: bel_simple_citation_1,
-            EVIDENCE: evidence_2,
-        })
-        assert_has_edge(self, fadd, casp8, graph, only=True, **{
-            RELATION: INCREASES,
-            ANNOTATIONS: {
-                'Species': [Entity(namespace='Species', identifier='10116')],
+        )
+        assert_has_edge(
+            self,
+            egfr,
+            casp8,
+            graph,
+            only=True,
+            **{
+                RELATION: DIRECTLY_DECREASES,
+                ANNOTATIONS: {
+                    "Species": [Entity(namespace="Species", identifier="9606")],
+                    "CellLine": [Entity(namespace="CellLine", identifier="10B9 cell")],
+                },
+                CITATION: bel_simple_citation_1,
+                EVIDENCE: evidence_2,
             },
-            CITATION: bel_simple_citation_2,
-            EVIDENCE: evidence_3,
-        })
-        assert_has_edge(self, akt1, casp8, graph, only=True, **{
-            RELATION: ASSOCIATION,
-            ANNOTATIONS: {
-                'Species': [Entity(namespace='Species', identifier='10116')],
+        )
+        assert_has_edge(
+            self,
+            fadd,
+            casp8,
+            graph,
+            only=True,
+            **{
+                RELATION: INCREASES,
+                ANNOTATIONS: {
+                    "Species": [Entity(namespace="Species", identifier="10116")],
+                },
+                CITATION: bel_simple_citation_2,
+                EVIDENCE: evidence_3,
             },
-            CITATION: bel_simple_citation_2,
-            EVIDENCE: evidence_3,
-        })
-        assert_has_edge(self, casp8, akt1, graph, only=True, **{
-            RELATION: ASSOCIATION,
-            ANNOTATIONS: {
-                'Species': [Entity(namespace='Species', identifier='10116')],
+        )
+        assert_has_edge(
+            self,
+            akt1,
+            casp8,
+            graph,
+            only=True,
+            **{
+                RELATION: ASSOCIATION,
+                ANNOTATIONS: {
+                    "Species": [Entity(namespace="Species", identifier="10116")],
+                },
+                CITATION: bel_simple_citation_2,
+                EVIDENCE: evidence_3,
             },
-            CITATION: bel_simple_citation_2,
-            EVIDENCE: evidence_3,
-        })
+        )
+        assert_has_edge(
+            self,
+            casp8,
+            akt1,
+            graph,
+            only=True,
+            **{
+                RELATION: ASSOCIATION,
+                ANNOTATIONS: {
+                    "Species": [Entity(namespace="Species", identifier="10116")],
+                },
+                CITATION: bel_simple_citation_2,
+                EVIDENCE: evidence_3,
+            },
+        )
 
     def bel_thorough_reconstituted(
         self,
@@ -351,8 +433,11 @@ class BelReconstitutionMixin(TestGraphMixin):
         self.assertIsInstance(graph, BELGraph)
 
         if check_warnings:
-            self.assertEqual(0, len(graph.warnings),
-                             msg='Document warnings:\n{}'.format('\n'.join(map(str, graph.warnings))))
+            self.assertEqual(
+                0,
+                len(graph.warnings),
+                msg="Document warnings:\n{}".format("\n".join(map(str, graph.warnings))),
+            )
 
         if check_metadata:
             self.assertLessEqual(set(expected_test_thorough_metadata), set(graph.document))
@@ -364,17 +449,25 @@ class BelReconstitutionMixin(TestGraphMixin):
             self.assertEqual(test_bel_thorough, graph.path)
 
         if check_provenance:
-            self.assertEqual({'CHEBI', 'HGNC', 'GO', 'MESHD', 'TESTNS2'}, set(graph.namespace_url))
-            self.assertEqual({'dbSNP'}, set(graph.namespace_pattern))
-            self.assertIn('TESTAN1', graph.annotation_list)
-            self.assertIn('TESTAN2', graph.annotation_list)
-            self.assertEqual(2, len(graph.annotation_list), msg='Wrong number of locally defined annotations')
-            self.assertEqual({'TestRegex'}, set(graph.annotation_pattern))
+            self.assertEqual({"CHEBI", "HGNC", "GO", "MESHD", "TESTNS2"}, set(graph.namespace_url))
+            self.assertEqual({"dbSNP"}, set(graph.namespace_pattern))
+            self.assertIn("TESTAN1", graph.annotation_list)
+            self.assertIn("TESTAN2", graph.annotation_list)
+            self.assertEqual(
+                2,
+                len(graph.annotation_list),
+                msg="Wrong number of locally defined annotations",
+            )
+            self.assertEqual({"TestRegex"}, set(graph.annotation_pattern))
 
         for node in graph:
             self.assertIsInstance(node, BaseEntity)
 
-        self.assertEqual(sorted(BEL_THOROUGH_NODES, key=str), sorted(graph, key=str), msg='Nodes not equal')
+        self.assertEqual(
+            sorted(BEL_THOROUGH_NODES, key=str),
+            sorted(graph, key=str),
+            msg="Nodes not equal",
+        )
 
         # FIXME
         # self.assertEqual(set((u, v) for u, v, _ in e), set(g.edges()))
@@ -435,48 +528,68 @@ class BelReconstitutionMixin(TestGraphMixin):
             ]
 
             for warning_tuple in graph.warnings:
-                self.assertEqual(3, len(warning_tuple), msg='Warning tuple is wrong size: {}'.format(warning_tuple))
+                self.assertEqual(
+                    3,
+                    len(warning_tuple),
+                    msg="Warning tuple is wrong size: {}".format(warning_tuple),
+                )
 
-            _sliced_warnings = [
-                (w.line_number, w.__class__)
-                for _, w, _ in graph.warnings
-            ]
-            self.assertEqual(expected_warnings, _sliced_warnings, msg='wrong warnings')
+            _sliced_warnings = [(w.line_number, w.__class__) for _, w, _ in graph.warnings]
+            self.assertEqual(expected_warnings, _sliced_warnings, msg="wrong warnings")
 
             for (el, ew), (_, exc, _) in zip(expected_warnings, graph.warnings):
                 self.assertIsInstance(exc, BELParserWarning)
                 self.assertIsInstance(exc.line, str)
                 self.assertIsInstance(exc.line_number, int)
                 self.assertIsInstance(exc.position, int)
-                self.assertEqual(el, exc.line_number, msg="Expected {} on line {} but got {} on line {}: {}".format(
-                    ew, el, exc.__class__, exc.line_number, exc
-                ))
-                self.assertIsInstance(exc, ew, msg='Line: {}'.format(el))
+                self.assertEqual(
+                    el,
+                    exc.line_number,
+                    msg="Expected {} on line {} but got {} on line {}: {}".format(
+                        ew, el, exc.__class__, exc.line_number, exc
+                    ),
+                )
+                self.assertIsInstance(exc, ew, msg="Line: {}".format(el))
 
         for node in graph:
             self.assertIsInstance(node, BaseEntity)
 
-        self.assertIn(akt1, graph, msg='AKT1 not in graph')
-        self.assertIn(egfr, graph, msg='EGFR not in graph')
+        self.assertIn(akt1, graph, msg="AKT1 not in graph")
+        self.assertIn(egfr, graph, msg="EGFR not in graph")
 
-        self.assertEqual(2, graph.number_of_nodes(), msg='Wrong number of nodes retrieved from slushy.bel')
-        self.assertEqual(1, graph.number_of_edges(), msg='Wrong nunber of edges retrieved from slushy.bel')
+        self.assertEqual(
+            2,
+            graph.number_of_nodes(),
+            msg="Wrong number of nodes retrieved from slushy.bel",
+        )
+        self.assertEqual(
+            1,
+            graph.number_of_edges(),
+            msg="Wrong nunber of edges retrieved from slushy.bel",
+        )
 
-        assert_has_edge(self, akt1, egfr, graph, only=True, **{
-            RELATION: INCREASES,
-            CITATION: citation_1,
-            EVIDENCE: evidence_1,
-        })
+        assert_has_edge(
+            self,
+            akt1,
+            egfr,
+            graph,
+            only=True,
+            **{
+                RELATION: INCREASES,
+                CITATION: citation_1,
+                EVIDENCE: evidence_1,
+            },
+        )
 
     def bel_isolated_reconstituted(self, graph: BELGraph):
         """Run the isolated node test."""
         self.assertIsNotNone(graph)
         self.assertIsInstance(graph, BELGraph)
 
-        adgrb1 = Protein(namespace='HGNC', name='ADGRB1')
-        adgrb2 = Protein(namespace='HGNC', name='ADGRB2')
+        adgrb1 = Protein(namespace="HGNC", name="ADGRB1")
+        adgrb2 = Protein(namespace="HGNC", name="ADGRB2")
         adgrb_complex = ComplexAbundance([adgrb1, adgrb2])
-        achlorhydria = Pathology(namespace='MESHD', name='Achlorhydria')
+        achlorhydria = Pathology(namespace="MESHD", name="Achlorhydria")
 
         for node in graph:
             self.assertIsInstance(node, BaseEntity)
