@@ -6,35 +6,91 @@ import unittest
 
 from pybel import BELGraph
 from pybel.constants import (
-    ACTIVITY, ANNOTATIONS, ASSOCIATION, CAUSES_NO_CHANGE, CITATION, CITATION_AUTHORS, CITATION_TYPE_PUBMED,
-    CITATION_TYPE_URL, DECREASES, DEGRADATION, DIRECTLY_DECREASES, DIRECTLY_INCREASES, EVIDENCE, GMOD, IDENTIFIER,
-    INCREASES, LOCATION, MODIFIER, NAMESPACE, POLAR_RELATIONS, POSITIVE_CORRELATION, RELATION, SOURCE_MODIFIER,
-    TARGET_MODIFIER, TRANSLOCATION,
+    ACTIVITY,
+    ANNOTATIONS,
+    ASSOCIATION,
+    CAUSES_NO_CHANGE,
+    CITATION,
+    CITATION_AUTHORS,
+    CITATION_TYPE_PUBMED,
+    CITATION_TYPE_URL,
+    DECREASES,
+    DEGRADATION,
+    DIRECTLY_DECREASES,
+    DIRECTLY_INCREASES,
+    EVIDENCE,
+    GMOD,
+    IDENTIFIER,
+    INCREASES,
+    LOCATION,
+    MODIFIER,
+    NAMESPACE,
+    POLAR_RELATIONS,
+    POSITIVE_CORRELATION,
+    RELATION,
+    SOURCE_MODIFIER,
+    TARGET_MODIFIER,
+    TRANSLOCATION,
 )
 from pybel.dsl import (
-    abundance, activity, degradation, fragment, gene, gmod, hgvs, pmod, protein, secretion, translocation,
+    abundance,
+    activity,
+    degradation,
+    fragment,
+    gene,
+    gmod,
+    hgvs,
+    pmod,
+    protein,
+    secretion,
+    translocation,
 )
 from pybel.language import Entity
 from pybel.struct.filters import false_node_predicate, true_node_predicate
 from pybel.struct.filters.edge_predicate_builders import build_relation_predicate
 from pybel.struct.filters.edge_predicates import (
-    edge_has_activity, edge_has_annotation, edge_has_degradation,
-    edge_has_translocation, has_authors, has_polarity, has_provenance, has_pubmed, is_associative_relation,
-    is_causal_relation, is_direct_causal_relation,
+    edge_has_activity,
+    edge_has_annotation,
+    edge_has_degradation,
+    edge_has_translocation,
+    has_authors,
+    has_polarity,
+    has_provenance,
+    has_pubmed,
+    is_associative_relation,
+    is_causal_relation,
+    is_direct_causal_relation,
 )
 from pybel.struct.filters.node_predicates import (
-    has_activity, has_causal_in_edges, has_causal_out_edges, has_fragment, has_gene_modification, has_hgvs,
-    has_protein_modification, has_variant, is_abundance, is_causal_central, is_causal_sink, is_causal_source,
-    is_degraded, is_gene, is_pathology, is_protein, is_translocated, none_of, not_pathology, one_of,
+    has_activity,
+    has_causal_in_edges,
+    has_causal_out_edges,
+    has_fragment,
+    has_gene_modification,
+    has_hgvs,
+    has_protein_modification,
+    has_variant,
+    is_abundance,
+    is_causal_central,
+    is_causal_sink,
+    is_causal_source,
+    is_degraded,
+    is_gene,
+    is_pathology,
+    is_protein,
+    is_translocated,
+    none_of,
+    not_pathology,
+    one_of,
 )
 from pybel.testing.utils import n
 
-p1 = protein(name='BRAF', namespace='HGNC')
-p2 = protein(name='BRAF', namespace='HGNC', variants=[hgvs('p.Val600Glu'), pmod('Ph')])
-p3 = protein(name='APP', namespace='HGNC', variants=fragment(start=672, stop=713))
-p4 = protein(name='2', namespace='HGNC')
+p1 = protein(name="BRAF", namespace="HGNC")
+p2 = protein(name="BRAF", namespace="HGNC", variants=[hgvs("p.Val600Glu"), pmod("Ph")])
+p3 = protein(name="APP", namespace="HGNC", variants=fragment(start=672, stop=713))
+p4 = protein(name="2", namespace="HGNC")
 
-g1 = gene(name='BRAF', namespace='HGNC', variants=gmod('Me'))
+g1 = gene(name="BRAF", namespace="HGNC", variants=gmod("Me"))
 
 
 class TestNodePredicates(unittest.TestCase):
@@ -129,37 +185,45 @@ class TestNodePredicates(unittest.TestCase):
         self.assertFalse(is_pathology(g1))
 
         self.assertTrue(has_variant(g1))
-        self.assertTrue(has_gene_modification(g1), msg='Should have {}: {}'.format(GMOD, g1))
+        self.assertTrue(has_gene_modification(g1), msg="Should have {}: {}".format(GMOD, g1))
         self.assertFalse(has_protein_modification(g1))
         self.assertFalse(has_hgvs(g1))
 
     def test_fragments(self):
-        self.assertTrue(has_fragment(
-            protein(name='APP', namespace='HGNC', variants=[fragment(start=672, stop=713, description='random text')])))
-        self.assertTrue(has_fragment(protein(name='APP', namespace='HGNC', variants=[fragment()])))
+        self.assertTrue(
+            has_fragment(
+                protein(
+                    name="APP",
+                    namespace="HGNC",
+                    variants=[fragment(start=672, stop=713, description="random text")],
+                )
+            )
+        )
+        self.assertTrue(has_fragment(protein(name="APP", namespace="HGNC", variants=[fragment()])))
 
     def test_p1_active(self):
         """cat(p(HGNC:HSD11B1)) increases deg(a(CHEBI:cortisol))"""
         g = BELGraph()
-        g.annotation_pattern['Species'] = r'\d+'
+        g.annotation_pattern["Species"] = r"\d+"
 
-        u = protein(name='HSD11B1', namespace='HGNC')
-        v = abundance(name='cortisol', namespace='CHEBI', identifier='17650')
+        u = protein(name="HSD11B1", namespace="HGNC")
+        v = abundance(name="cortisol", namespace="CHEBI", identifier="17650")
 
         g.add_increases(
             u,
             v,
             citation={
-                NAMESPACE: CITATION_TYPE_URL, IDENTIFIER: 'https://www.ncbi.nlm.nih.gov/gene/3290'
+                NAMESPACE: CITATION_TYPE_URL,
+                IDENTIFIER: "https://www.ncbi.nlm.nih.gov/gene/3290",
             },
             evidence="Entrez Gene Summary: Human: The protein encoded by this gene is a microsomal enzyme that "
-                     "catalyzes the conversion of the stress hormone cortisol to the inactive metabolite cortisone. "
-                     "In addition, the encoded protein can catalyze the reverse reaction, the conversion of cortisone "
-                     "to cortisol. Too much cortisol can lead to central obesity, and a particular variation in this "
-                     "gene has been associated with obesity and insulin resistance in children. Two transcript "
-                     "variants encoding the same protein have been found for this gene.",
-            annotations={'Species': '9606'},
-            source_modifier=activity('cat'),
+            "catalyzes the conversion of the stress hormone cortisol to the inactive metabolite cortisone. "
+            "In addition, the encoded protein can catalyze the reverse reaction, the conversion of cortisone "
+            "to cortisol. Too much cortisol can lead to central obesity, and a particular variation in this "
+            "gene has been associated with obesity and insulin resistance in children. Two transcript "
+            "variants encoding the same protein have been found for this gene.",
+            annotations={"Species": "9606"},
+            source_modifier=activity("cat"),
             target_modifier=degradation(),
         )
 
@@ -174,21 +238,21 @@ class TestNodePredicates(unittest.TestCase):
     def test_object_has_translocation(self):
         """p(HGNC: EGF) increases tloc(p(HGNC: VCP), GO:0005634, GO:0005737)"""
         g = BELGraph()
-        g.annotation_pattern['Species'] = r'\d+'
-        u = protein(name='EFG', namespace='HGNC')
-        v = protein(name='VCP', namespace='HGNC')
+        g.annotation_pattern["Species"] = r"\d+"
+        u = protein(name="EFG", namespace="HGNC")
+        v = protein(name="VCP", namespace="HGNC")
 
         g.add_increases(
             u,
             v,
-            citation='10855792',
+            citation="10855792",
             evidence="Although found predominantly in the cytoplasm and, less abundantly, in the nucleus, VCP can be "
-                     "translocated from the nucleus after stimulation with epidermal growth factor.",
-            annotations={'Species': '9606'},
+            "translocated from the nucleus after stimulation with epidermal growth factor.",
+            annotations={"Species": "9606"},
             target_modifier=translocation(
-                from_loc=Entity(namespace='GO', identifier='0005634'),
-                to_loc=Entity(namespace='GO', identifier='0005737'),
-            )
+                from_loc=Entity(namespace="GO", identifier="0005634"),
+                to_loc=Entity(namespace="GO", identifier="0005737"),
+            ),
         )
 
         self.assertFalse(is_translocated(g, u))
@@ -206,21 +270,21 @@ class TestNodePredicates(unittest.TestCase):
     def test_object_has_secretion(self):
         """p(MGI:Il4) increases sec(p(MGI:Cxcl1))"""
         g = BELGraph()
-        g.annotation_pattern['Species'] = r'\d+'
-        g.annotation_pattern['MeSH'] = '.*'
-        u = protein(name='Il4', namespace='MGI')
-        v = protein(name='Cxcl1', namespace='MGI')
+        g.annotation_pattern["Species"] = r"\d+"
+        g.annotation_pattern["MeSH"] = ".*"
+        u = protein(name="Il4", namespace="MGI")
+        v = protein(name="Cxcl1", namespace="MGI")
 
         g.add_increases(
             u,
             v,
-            citation='10072486',
-            evidence='Compared with controls treated with culture medium alone, IL-4 and IL-5 induced significantly '
-                     'higher levels of MIP-2 and KC production; IL-4 also increased the production of MCP-1 '
-                     '(Fig. 2, A and B)....we only tested the effects of IL-3, IL-4, IL-5, and IL-13 on chemokine '
-                     'expression and cellular infiltration....Recombinant cytokines were used, ... to treat naive '
-                     'BALB/c mice.',
-            annotations={'Species': '10090', 'MeSH': 'bronchoalveolar lavage fluid'},
+            citation="10072486",
+            evidence="Compared with controls treated with culture medium alone, IL-4 and IL-5 induced significantly "
+            "higher levels of MIP-2 and KC production; IL-4 also increased the production of MCP-1 "
+            "(Fig. 2, A and B)....we only tested the effects of IL-3, IL-4, IL-5, and IL-13 on chemokine "
+            "expression and cellular infiltration....Recombinant cytokines were used, ... to treat naive "
+            "BALB/c mice.",
+            annotations={"Species": "10090", "MeSH": "bronchoalveolar lavage fluid"},
             target_modifier=secretion(),
         )
 
@@ -239,19 +303,19 @@ class TestNodePredicates(unittest.TestCase):
     def test_subject_has_secretion(self):
         """sec(p(MGI:S100b)) increases a(CHEBI:"nitric oxide")"""
         g = BELGraph()
-        g.annotation_pattern['Species'] = r'\d+'
-        g.annotation_pattern['Cell'] = r'.*'
-        u = protein(name='S100b', namespace='MGI')
-        v = abundance(name='nitric oxide', namespace='CHEBI')
+        g.annotation_pattern["Species"] = r"\d+"
+        g.annotation_pattern["Cell"] = r".*"
+        u = protein(name="S100b", namespace="MGI")
+        v = abundance(name="nitric oxide", namespace="CHEBI")
 
         g.add_increases(
             u,
             v,
-            citation='11180510',
-            evidence='S100B protein is also secreted by astrocytes and acts on these cells to stimulate nitric oxide '
-                     'secretion in an autocrine manner.',
-            annotations={'Species': '10090', 'Cell': 'astrocyte'},
-            source_modifier=secretion()
+            citation="11180510",
+            evidence="S100B protein is also secreted by astrocytes and acts on these cells to stimulate nitric oxide "
+            "secretion in an autocrine manner.",
+            annotations={"Species": "10090", "Cell": "astrocyte"},
+            source_modifier=secretion(),
         )
 
         self.assertTrue(is_translocated(g, u))
@@ -269,9 +333,9 @@ class TestNodePredicates(unittest.TestCase):
     def test_node_exclusion_data(self):
         g = BELGraph()
 
-        u = protein(name='S100b', namespace='MGI')
-        v = abundance(name='nitric oxide', namespace='CHEBI')
-        w = abundance(name='cortisol', namespace='CHEBI', identifier='17650')
+        u = protein(name="S100b", namespace="MGI")
+        v = abundance(name="nitric oxide", namespace="CHEBI")
+        w = abundance(name="cortisol", namespace="CHEBI", identifier="17650")
 
         g.add_node_from_data(u)
         g.add_node_from_data(v)
@@ -298,9 +362,9 @@ class TestNodePredicates(unittest.TestCase):
     def test_node_exclusion_tuples(self):
         g = BELGraph()
 
-        u = protein(name='S100b', namespace='MGI')
-        v = abundance(name='nitric oxide', namespace='CHEBI')
-        w = abundance(name='cortisol', namespace='CHEBI', identifier='17650')
+        u = protein(name="S100b", namespace="MGI")
+        v = abundance(name="nitric oxide", namespace="CHEBI")
+        w = abundance(name="cortisol", namespace="CHEBI", identifier="17650")
 
         g.add_node_from_data(u)
         g.add_node_from_data(v)
@@ -327,9 +391,9 @@ class TestNodePredicates(unittest.TestCase):
     def test_node_inclusion_data(self):
         g = BELGraph()
 
-        u = protein(name='S100b', namespace='MGI')
-        v = abundance(name='nitric oxide', namespace='CHEBI')
-        w = abundance(name='cortisol', namespace='CHEBI', identifier='17650')
+        u = protein(name="S100b", namespace="MGI")
+        v = abundance(name="nitric oxide", namespace="CHEBI")
+        w = abundance(name="cortisol", namespace="CHEBI", identifier="17650")
 
         g.add_node_from_data(u)
         g.add_node_from_data(v)
@@ -356,9 +420,9 @@ class TestNodePredicates(unittest.TestCase):
     def test_node_inclusion_tuples(self):
         g = BELGraph()
 
-        u = protein(name='S100b', namespace='MGI')
-        v = abundance(name='nitric oxide', namespace='CHEBI')
-        w = abundance(name='cortisol', namespace='CHEBI', identifier='17650')
+        u = protein(name="S100b", namespace="MGI")
+        v = abundance(name="nitric oxide", namespace="CHEBI")
+        w = abundance(name="cortisol", namespace="CHEBI", identifier="17650")
 
         g.add_node_from_data(u)
         g.add_node_from_data(v)
@@ -421,8 +485,8 @@ class TestEdgePredicate(unittest.TestCase):
     def test_has_provenance(self):
         self.assertFalse(has_provenance({}))
         self.assertFalse(has_provenance({CITATION: {}}))
-        self.assertFalse(has_provenance({EVIDENCE: ''}))
-        self.assertTrue(has_provenance({CITATION: {}, EVIDENCE: ''}))
+        self.assertFalse(has_provenance({EVIDENCE: ""}))
+        self.assertTrue(has_provenance({CITATION: {}, EVIDENCE: ""}))
 
     def test_has_pubmed(self):
         self.assertTrue(has_pubmed({CITATION: {NAMESPACE: CITATION_TYPE_PUBMED}}))
@@ -433,7 +497,7 @@ class TestEdgePredicate(unittest.TestCase):
         self.assertFalse(has_authors({}))
         self.assertFalse(has_authors({CITATION: {}}))
         self.assertFalse(has_authors({CITATION: {CITATION_AUTHORS: []}}))
-        self.assertTrue(has_authors({CITATION: {CITATION_AUTHORS: ['One guy']}}))
+        self.assertTrue(has_authors({CITATION: {CITATION_AUTHORS: ["One guy"]}}))
 
     def test_is_causal(self):
         self.assertTrue(is_causal_relation({RELATION: INCREASES}))
@@ -520,8 +584,8 @@ class TestEdgePredicate(unittest.TestCase):
         self.assertFalse(edge_has_activity({TARGET_MODIFIER: {MODIFIER: DEGRADATION}}))
 
     def test_has_annotation(self):
-        self.assertFalse(edge_has_annotation({}, 'Subgraph'))
-        self.assertFalse(edge_has_annotation({ANNOTATIONS: {}}, 'Subgraph'))
-        self.assertFalse(edge_has_annotation({ANNOTATIONS: {'Subgraph': None}}, 'Subgraph'))
-        self.assertTrue(edge_has_annotation({ANNOTATIONS: {'Subgraph': 'value'}}, 'Subgraph'))
-        self.assertFalse(edge_has_annotation({ANNOTATIONS: {'Nope': 'value'}}, 'Subgraph'))
+        self.assertFalse(edge_has_annotation({}, "Subgraph"))
+        self.assertFalse(edge_has_annotation({ANNOTATIONS: {}}, "Subgraph"))
+        self.assertFalse(edge_has_annotation({ANNOTATIONS: {"Subgraph": None}}, "Subgraph"))
+        self.assertTrue(edge_has_annotation({ANNOTATIONS: {"Subgraph": "value"}}, "Subgraph"))
+        self.assertFalse(edge_has_annotation({ANNOTATIONS: {"Nope": "value"}}, "Subgraph"))
