@@ -15,23 +15,23 @@ class TestNodeSelection(unittest.TestCase):
     def test_get_node_by_namespace(self):
         """Test getting nodes with a given namespace."""
         g = BELGraph()
-        a = Protein(namespace='N1', name='a')
-        b = Protein(namespace='N1', name='b')
-        c = Protein(namespace='N2', name='c')
-        d = Protein(namespace='N3', name='d')
+        a = Protein(namespace="N1", name="a")
+        b = Protein(namespace="N1", name="b")
+        c = Protein(namespace="N2", name="c")
+        d = Protein(namespace="N3", name="d")
         g.add_node_from_data(a)
         g.add_node_from_data(b)
         g.add_node_from_data(c)
         g.add_node_from_data(d)
 
-        nodes = set(get_nodes_by_namespace(g, 'N1'))
+        nodes = set(get_nodes_by_namespace(g, "N1"))
 
         self.assertIn(a, nodes)
         self.assertIn(b, nodes)
         self.assertNotIn(c, nodes)
         self.assertNotIn(d, nodes)
 
-        nodes = set(get_nodes_by_namespace(g, ('N1', 'N2')))
+        nodes = set(get_nodes_by_namespace(g, ("N1", "N2")))
 
         self.assertIn(a, nodes)
         self.assertIn(b, nodes)
